Module models

Module models 

OCI specification model types.

Structs

Config
Represents the config block inside of an image config and frequently utilized fields
ConfigBuilder
Use builder syntax to set the inputs and finish with build().
DockerAuth
DockerConfig
View model for the common docker/finch config for finding authorizations
ErrorInfo
The standard specification of an error returned from an OCI registry.
ErrorResponse
History
Represents a history log entry in an image config
HistoryBuilder
Use builder syntax to set the inputs and finish with build().
ImageConfig
Represents the shape of an image configuration blob
ImageConfigBuilder
Use builder syntax to set the inputs and finish with build().
Platform
Represents the frequently used platform identifiers both in json format and as the commandline / format.
PlatformBuilder
Use builder syntax to set the inputs and finish with build().
TarballManifest
This defines the format of a manifest.json file in a tarball representation of an image that docker/podman/finch/nerdctl can use load on.
TarballManifestBuilder
Use builder syntax to set the inputs and finish with build().

Enums

Compression
Helper enum to specify the compression algorithm used with a layer
ErrorCode
The officially supported error codes as defined by the OCI distribution specification.
MediaType
Handles all the supported media type enumerations by this tool. Since OCI specification allows custom types this is rather limited currently but should be expanded to treat any unrecognized MediaType as a Custom variant
Token
Represents an authorization token