OCI specification model types.
Structs
- Config
- Represents the config block inside of an image config and frequently utilized fields
- Config
Builder - Use builder syntax to set the inputs and finish with
build(). - Docker
Auth - Docker
Config - View model for the common docker/finch config for finding authorizations
- Error
Info - The standard specification of an error returned from an OCI registry.
- Error
Response - History
- Represents a history log entry in an image config
- History
Builder - Use builder syntax to set the inputs and finish with
build(). - Image
Config - Represents the shape of an image configuration blob
- Image
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Platform
- Represents the frequently used platform identifiers both in json format and as the
commandline
/ format. - Platform
Builder - Use builder syntax to set the inputs and finish with
build(). - Tarball
Manifest - This defines the format of a manifest.json file in a tarball representation of an image that docker/podman/finch/nerdctl can use load on.
- Tarball
Manifest Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- Compression
- Helper enum to specify the compression algorithm used with a layer
- Error
Code - The officially supported error codes as defined by the OCI distribution specification.
- Media
Type - Handles all the supported media type enumerations by this tool. Since OCI specification allows custom types this is rather limited currently but should be expanded to treat any unrecognized MediaType as a Custom variant
- Token
- Represents an authorization token